==> ocre_v0_031.tgz: ocre-0.031/ocre/src/pauta.c <==

#include <stdio.h>
#include <string.h>

#include "asocia.h"
#include "base.h"
#include "convcar.h"
#include "distrib.h"
#include "glifos.h"
#include "opcns.h"

/* --------------- ---------------*/

static int nlposy;
static char ** posy0, ** posy1, **posy2;

void leePosyes ()
{
  leeT3 (a_valor, "../conv/tposyes", &posy0 , &posy1, &posy2, &nlposy) ;
}

Boolean posicionPautasDeCaracter (int *dp1, int *dp2, char *cars, int ty)
{
  Boolean conoc;
  int dyn1, dyn2;
  char nm1[6], nm2[6];
  conoc = FALSE;
  if ( asocT3(cars, nm1, nm2, posy0, posy1, posy2, nlposy) ) {
    conoc = TRUE;
    dyn1 = numDeStrDec3 (nm1) ;
    dyn2 = numDeStrDec3 (nm2) ;
    *dp1 = ty * (112 - dyn1) / (dyn2 - dyn1) ;
    *dp2 = ty * (144 - dyn1) / (dyn2 - dyn1) ;
    }
  return conoc;
}

/*
Boolean posicionPautasDeCaracter2 (int *dp1, int *dp2, char *cars, int ty)
{
  Boolean conoc;
  int dyn1, dyn2;
  conoc = FALSE;
  if (strlen(cars) == 1)
    {
    if ((cars[0] == 'a') || (cars[0] == 'e')) {
      dyn1 = 112; dyn2 = 144; conoc = TRUE;
      }
    if ((cars[0] == 'A') || (cars[0] == 'E')) {
      dyn1 =  92; dyn2 = 144; conoc = TRUE;
      }
    if (conoc) {
      *dp1 = ty * (112 - dyn1) / (dyn2 - dyn1) ;
      *dp2 = ty * (144 - dyn1) / (dyn2 - dyn1) ;
      }
    }
  return conoc;
}
*/

static int delp1[400], delp2[400], ndgl, ngl;

void informa1pauta (tglifo glifo, tpgen gn)
{
  int *n = (int *) gn;
  int base, alturax;
  int dy, ty, p1, p2, dp1, dp2 ;
  int del1, del2;
  tvent vent;
  if (glifo->recon != reconNulo) {
    ngl++;
    (*n)++;
    vent = glifo->venDeGlifo;
    baseyalturaxDeGlifo (&base, &alturax, glifo);
    dy = vent->dy;
    ty = vent->ty;
    if ( posicionPautasDeCaracter(&dp1, &dp2, glifo->letras, ty) ) {
      p1 = dp1 + dy;
      p2 = dp2 + dy;
      del1 = p1 - alturax;
      del2 = p2 - base;
      if ((abs(del1) > (2 + ty/15)) ||
          (abs(del2) > (2 + ty/15))    ) {
        // printf ("del1:%4d, del2:%4d, p1: %4d, p2: %4d ", del1, del2, p1, p2);
        // printf ("base: %4d, alturax: %4d, txt:%4s, alt:%4d, bj:%4d\n",
        //          base,      alturax, glifo->letras, dy,     dy+ty);
	delp1[ndgl] = del1;
	delp2[ndgl] = del2;
	ndgl ++;
        }
      }
//    printf ("base: %4d, alturax: %4d, txt:%4s, alt:%4d, bj:%4d\n",
//             base,      alturax, glifo->letras, dy,     dy+ty);
    }
}

void informaPautas (tglifo glifoLinea)
{
  int nMay;
  nMay  = 0;
  leePosyes ();
  aplicaGtRFncD (glifoLinea, glifCar, informa1pauta, (tpgen) &nMay);

}

void repasaPautasenLinea (tglifo glifoLinea)
{
  int cg1[100], cg2[100];
  int ng1, ng2;
  ngl = 0;
  ndgl = 0;
  informaPautas (glifoLinea);
  if (ndgl != 0) {
    agrupa (cg1, &ng1, delp1, ndgl, 3);
    agrupa (cg2, &ng2, delp2, ndgl, 3);
    // describeGlifo (glifoLinea, 3);  //
    //printf ("deltas: ndgl:%3d, ng1:%3d, cg1[0]:%3d, ng2:%3d, cg2[0]:%3d, ngl:%3d\n",  //
     //                ndgl,     ng1,     cg1[0],     ng2,     cg2[0]    , ngl);        //
    if (ng1 == 1)           // unanimidad
      glifoLinea->alturax += cg1[0];
    if (ng2 == 1)           // unanimidad
      glifoLinea->base    += cg2[0];
    }
}

void repasaPautas (tglifo glifoColumnaP)
{
  aplicaGtRFn (glifoColumnaP, glifCompLin, repasaPautasenLinea);
}

/* --------------- ---------------*/

// cambia:
//    u002c (coma) por u2019 (comilla 9 alta)
void corregirGlifocharPorPosy (tglifo glifoChar)
{
  int dyNorm, dy2Norm, tyNorm;
  if (strcmp(glifoChar->letras, "\x2c") ==0){
    alineamientoNormalizado (&dyNorm, &dy2Norm, &tyNorm, glifoChar);
    if ((dy2Norm + dyNorm)/2 < 128) {
      // printf ("corregirGlifocharPorPosy, dy2: %4d dy %4d\n", dy2Norm, dyNorm);
      ponLetGlifo (glifoChar, "\xe2\x80\x99");
      }
    }
}

==> ocre_v0_042.tgz: ocre-0.042/ocre/src/pauta.c <==

#include <stdio.h>
#include <string.h>

#include "asocia.h"
#include "base.h"
#include "convcar.h"
#include "distrib.h"
#include "glifos.h"
#include "opcns.h"

/* --------------- ---------------*/

static int nlposy;
static char ** posy0, ** posy1, **posy2;

void leePosyes ()
{
  leeT3 (a_valor, "../conv/tposyes", &posy0 , &posy1, &posy2, &nlposy) ;
}

Boolean posicionPautasDeCaracter (int *dp1, int *dp2, char *cars, int ty)
{
  Boolean conoc;
  int dyn1, dyn2;
  char nm1[6], nm2[6];
  conoc = FALSE;
  if ( asocT3(cars, nm1, nm2, posy0, posy1, posy2, nlposy) ) {
    conoc = TRUE;
    dyn1 = numDeStrDec3 (nm1) ;
    dyn2 = numDeStrDec3 (nm2) ;
    *dp1 = ty * (112 - dyn1) / (dyn2 - dyn1) ;
    *dp2 = ty * (144 - dyn1) / (dyn2 - dyn1) ;
    }
  return conoc;
}

/*
Boolean posicionPautasDeCaracter2 (int *dp1, int *dp2, char *cars, int ty)
{
  Boolean conoc;
  int dyn1, dyn2;
  conoc = FALSE;
  if (strlen(cars) == 1)
    {
    if ((cars[0] == 'a') || (cars[0] == 'e')) {
      dyn1 = 112; dyn2 = 144; conoc = TRUE;
      }
    if ((cars[0] == 'A') || (cars[0] == 'E')) {
      dyn1 =  92; dyn2 = 144; conoc = TRUE;
      }
    if (conoc) {
      *dp1 = ty * (112 - dyn1) / (dyn2 - dyn1) ;
      *dp2 = ty * (144 - dyn1) / (dyn2 - dyn1) ;
      }
    }
  return conoc;
}
*/

static int delp1[400], delp2[400], ndgl, ngl;

void informa1pauta (tglifo glifo, tpgen gn)
{
  int *n = (int *) gn;
  int base, alturax;
  int dy, ty, p1, p2, dp1, dp2 ;
  int del1, del2;
  tvent vent;
  if (glifo->recon != reconNulo) {
    ngl++;
    (*n)++;
    vent = glifo->venDeGlifo;
    baseyalturaxDeGlifo (&base, &alturax, glifo);
    dy = vent->dy;
    ty = vent->ty;
    if ( posicionPautasDeCaracter(&dp1, &dp2, glifo->letras, ty) ) {
      p1 = dp1 + dy;
      p2 = dp2 + dy;
      del1 = p1 - alturax;
      del2 = p2 - base;
      if ((abs(del1) > (2 + ty/15)) ||
          (abs(del2) > (2 + ty/15))    ) {
        // printf ("del1:%4d, del2:%4d, p1: %4d, p2: %4d ", del1, del2, p1, p2);
        // printf ("base: %4d, alturax: %4d, txt:%4s, alt:%4d, bj:%4d\n",
        //          base,      alturax, glifo->letras, dy,     dy+ty);
	delp1[ndgl] = del1;
	delp2[ndgl] = del2;
	ndgl ++;
        }
      }
//    printf ("base: %4d, alturax: %4d, txt:%4s, alt:%4d, bj:%4d\n",
//             base,      alturax, glifo->letras, dy,     dy+ty);
    }
}

void informaPautas (tglifo glifoLinea)
{
  int nMay;
  nMay  = 0;
  leePosyes ();
  aplicaGtRFncD (glifoLinea, glifCar, informa1pauta, (tpgen) &nMay);

}

void corregirGlifocharPorPosy0 (tglifo glifoChar);

void repasaPautasenLinea (tglifo glifoLinea)
{
  int cg1[100], cg2[100];
  int ng1, ng2;
  ngl = 0;
  ndgl = 0;
  informaPautas (glifoLinea);
  if (ndgl != 0) {
    agrupa (cg1, &ng1, delp1, ndgl, 3);
    agrupa (cg2, &ng2, delp2, ndgl, 3);
    // describeGlifo (glifoLinea, 3);  //
    //printf ("deltas: ndgl:%3d, ng1:%3d, cg1[0]:%3d, ng2:%3d, cg2[0]:%3d, ngl:%3d\n",  //
     //                ndgl,     ng1,     cg1[0],     ng2,     cg2[0]    , ngl);        //
    if (ng1 == 1)           // unanimidad
      glifoLinea->alturax += cg1[0];
    if (ng2 == 1)           // unanimidad
      glifoLinea->base    += cg2[0];
    aplicaGtRFn (glifoLinea, glifCar, corregirGlifocharPorPosy0);
    }
}

void repasaPautas (tglifo glifoColumnaP)
{
  aplicaGtRFn (glifoColumnaP, glifCompLin, repasaPautasenLinea);
}

/* --------------- ---------------*/

// cambia:
void corregirGlifocharPorPosy (tglifo glifoChar, char *lets)
{
  int dyNorm, dy2Norm, tyNorm;
  // u002c (coma) por u2019 (comilla 9 alta)
  alineamientoNormalizado (&dyNorm, &dy2Norm, &tyNorm, glifoChar);
  // printf ("corregirGlifocharPorPosy, %s dy2: %4d dy %4d\n",
  //                       glifoChar->letras, dy2Norm, dyNorm);
  if (strcmp(glifoChar->letras, "\x2c") ==0){
    alineamientoNormalizado (&dyNorm, &dy2Norm, &tyNorm, glifoChar);
    if ((dy2Norm + dyNorm)/2 < 128) {
      // printf ("corregirGlifocharPorPosy, dy2: %4d dy %4d\n", dy2Norm, dyNorm);
      ponLetGlifo (glifoChar, "\xe2\x80\x99");
      lets = strdup ("\xe2\x80\x99");
      }
    }
  // u004f (O) por u006f (o)
  else if (strcmp(glifoChar->letras, "\x4f") ==0){
    alineamientoNormalizado (&dyNorm, &dy2Norm, &tyNorm, glifoChar);
    if (dyNorm >  106) {
      // printf ("%s ", glifoChar->letras);
      // printf ("corregirGlifocharPorPosy, dy2: %4d dy %4d\n", dy2Norm, dyNorm);
      ponLetGlifo (glifoChar, "\x6f");
      lets = strdup ("\x6f");
      }
    }
  // u0053 (S) por u0073 (s)
  else if (strcmp(glifoChar->letras, "\x53") ==0){
    alineamientoNormalizado (&dyNorm, &dy2Norm, &tyNorm, glifoChar);
    if (dyNorm >  106) {
      // printf ("%s ", glifoChar->letras);
      // printf ("corregirGlifocharPorPosy, dy2: %4d dy %4d\n", dy2Norm, dyNorm);
      ponLetGlifo (glifoChar, "\x73");
      lets = strdup ("\x73");
      }
    }
}

void corregirGlifocharPorPosy0 (tglifo glifoChar)
{
  char nada[128];
  corregirGlifocharPorPosy (glifoChar, nada);
}
